@@ -66,8 +66,8 @@ struct _NcGalaxyAcf
 GType nc_galaxy_acf_get_type (void) G_GNUC_CONST;
 
 NcGalaxyAcf *nc_galaxy_acf_new (NcGrowthFunc *gf, NcDistance *dist, NcTransferFunc *tf);
-gdouble ncm_galaxy_acf_psi (NcGalaxyAcf *acf, NcHICosmo *model, gdouble k, guint l);
-void ncm_galaxy_acf_prepare_psi (NcGalaxyAcf *acf, NcHICosmo *model, guint l);
+gdouble nc_galaxy_acf_psi (NcGalaxyAcf *acf, NcHICosmo *model, gdouble k, guint l);
+void nc_galaxy_acf_prepare_psi (NcGalaxyAcf *acf, NcHICosmo *model, guint l);
 
 
 G_END_DECLS
