@@ -202,7 +202,7 @@ nc_growth_func_prepare (NcGrowthFunc *gf, NcHICosmo *model)
   while (TRUE)
   {
     gint flag = CVode (gf->cvode, 0.0, gf->yv, &z, CV_ONE_STEP);
-    if (!nc_cvode_util_check_flag (&flag, "CVode", 1))
+    if (!ncm_cvode_util_check_flag (&flag, "CVode", 1))
       g_error ("nc_growth_func_prepare: cannot integrate function.");
 
     if (zf == z && ii++ > 10)
