@@ -26,7 +26,9 @@
 #ifndef _NC_TRANSFER_FUNC_BBKS_H_
 #define _NC_TRANSFER_FUNC_BBKS_H_
 
+#include <glib.h>
 #include <glib-object.h>
+#include <numcosmo/lss/nc_transfer_func.h>
 
 G_BEGIN_DECLS
 
