@@ -32,11 +32,11 @@
 
 G_BEGIN_DECLS
 
-void nc_interp_dd_init (const gdouble *vx, gdouble *dd, const gint np, const gint nf);
-gdouble nc_interp_dd_eval (const gdouble *vx, const gdouble *dd, const gdouble x, const gint np, const gint nf);
+void ncm_interp_dd_init (const gdouble *vx, gdouble *dd, const gint np, const gint nf);
+gdouble ncm_interp_dd_eval (const gdouble *vx, const gdouble *dd, const gdouble x, const gint np, const gint nf);
 
-void nc_interp_dd_init_2_4 (const gdouble *vx, gdouble *dd);
-gdouble nc_interp_dd_eval_2_4 (const gdouble *vx, const gdouble *dd, const gdouble x);
+void ncm_interp_dd_init_2_4 (const gdouble *vx, gdouble *dd);
+gdouble ncm_interp_dd_eval_2_4 (const gdouble *vx, const gdouble *dd, const gdouble x);
 
 G_END_DECLS
 
