@@ -38,7 +38,6 @@
 #endif
 #include <numcosmo/math/ncm_spline.h>
 
-
 G_BEGIN_DECLS
 
 void ncm_cfg_init (void);
@@ -92,14 +91,129 @@ LOAD_SAVE_VECTOR_MATRIX_DEF(complex)
 sqlite3 *ncm_cfg_get_default_sqlite3 (void);
 #endif
 
-#define NC_CFG_DEFAULT_SQLITE3_FILENAME "data_observation.sqlite3"
-
 typedef union _NcmDoubleInt64
 {
   gint64 i;
   gdouble x;
 } NcmDoubleInt64;
 
+gchar *ncm_cfg_command_line (gchar *argv[], gint argc);
+
+void ncm_cfg_object_set_property (GObject *obj, const gchar *prop_str);
+GObject *ncm_cfg_create_from_name_params (const gchar *obj_name, GVariant *params);
+GObject *ncm_cfg_create_from_string (const gchar *obj_ser);
+GVariant *ncm_cfg_gvalue_to_gvariant (GValue *val);
+GVariant *ncm_cfg_serialize_to_variant (GObject *obj);
+gchar *ncm_cfg_serialize_to_string (GObject *obj, gboolean valid_variant);
+
+/* Macros */
+
+#ifdef SUNDIALS_USES_LONG_INT
+#define _NCM_SUNDIALS_INT_TYPE glong
+#else
+#define _NCM_SUNDIALS_INT_TYPE gint
+#endif
+
+#if (GLIB_MAJOR_VERSION == 2) && (GLIB_MINOR_VERSION < 32)
+#define _NCM_MUTEX_LOCK(l) g_static_mutex_lock (l)
+#define _NCM_MUTEX_UNLOCK(l) g_static_mutex_unlock (l)
+#define _NCM_MUTEX_TRYLOCK(l) g_static_mutex_trylock (l)
+#define _NCM_MUTEX_TYPE GStaticMutex
+#define _NCM_STATIC_MUTEX_DECL(l) static GStaticMutex l = G_STATIC_MUTEX_INIT
+#define _NCM_MUTEX_INIT(l) g_static_mutex_init (l)
+#define _NCM_MUTEX_CLEAR(l) g_static_mutex_free (l)
+#else
+#define _NCM_MUTEX_LOCK(l) g_mutex_lock (l)
+#define _NCM_MUTEX_UNLOCK(l) g_mutex_unlock (l)
+#define _NCM_MUTEX_TRYLOCK(l) g_mutex_trylock (l)
+#define _NCM_MUTEX_TYPE GMutex
+#define _NCM_STATIC_MUTEX_DECL(l) static GMutex l
+#define _NCM_MUTEX_INIT(l) g_mutex_init (l)
+#define _NCM_MUTEX_CLEAR(l) g_mutex_clear (l)
+#endif
+
+#define NCM_RETURN_IF_INF(a) if (gsl_isinf(a)) return a
+
+#define NCM_FLOOR_TRUNC(a,b) (floor ((b) * (a)) / (b))
+#define NCM_CEIL_TRUNC(a,b) (ceil ((b) * (a)) / (b))
+#define NCM_ROUND_TRUNC(a,b) (round ((b) * (a)) / (b))
+
+#define NCM_TEST_GSL_RESULT(func,ret) if (ret != GSL_SUCCESS) g_error ("%s: %s", func, gsl_strerror (ret))
+
+#define NCM_ZERO_LIMIT 1e-13
+#define NCM_DEFAULT_PRECISION 1e-7
+
+#ifndef NCM_THREAD_POOL_MAX
+#define NCM_THREAD_POOL_MAX 5
+#endif
+
+#define NCM_MAP_ALM_SIZE(lmax) (((lmax)*(lmax) + 3*(lmax) + 2)/2)
+#define NCM_MAP_N_IND_PLM(lmax) (((lmax)*(lmax) + 3*(lmax) + 2)/2)
+#define NCM_MAP_MAX_RING_SIZE(nside) (4*(nside))
+#define NCM_MAP_N_DIFFERENT_SIZED_RINGS(nside) (nside)
+#define NCM_MAP_RING_PLAN_INDEX(nside,ring_n) (((ring_n) < (nside)) ? (ring_n) : ((ring_n)>=(3*(nside)) ? (4*(nside)-(ring_n)-2) : ((nside)-1)))
+#define NCM_MAP_RING_SIZE(nside,ring_n) (4*(NCM_MAP_RING_PLAN_INDEX(nside,ring_n)+1))
+#define NCM_MAP_N_RINGS(nside) (4*(nside)-1)
+#define NCM_MAP_ALM_M_START(lmax,m) ((2*(lmax)*(m)-(m)*(m)+3*(m))/2)
+#define NCM_MAP_ALM_INDEX(lmax,l,m) (((l) >= (m)) ? (NCM_MAP_ALM_M_START(lmax,m) + (l) - (m)) : (-1))
+
+#ifndef mpz_inits
+#define mpz_inits ncm_mpz_inits
+#endif /* mpz_inits */
+
+#ifndef mpz_clears
+#define mpz_clears ncm_mpz_clears
+#endif /* mpz_inits */
+
+#define NCM_COMPLEX_INC_MUL_REAL_TEST(a,b,c) \
+((fabs(GSL_REAL((b))*(c)/GSL_REAL((a))) < 1e-16) && (fabs(GSL_IMAG((b))*(c)/GSL_IMAG((a))) < 1e-16))
+
+#define NCM_COMPLEX_INC_MUL_REAL(a,b,c) \
+do { \
+  GSL_REAL((a)) += GSL_REAL((b))*(c); \
+  GSL_IMAG((a)) += GSL_IMAG((b))*(c); \
+} while (FALSE)
+
+#define NCM_COMPLEX_INC_MUL(a,b,c) \
+do { \
+  GSL_REAL((a)) += GSL_REAL((b)) * GSL_REAL((c)) - GSL_IMAG((b)) * GSL_IMAG((c)); \
+  GSL_IMAG((a)) += GSL_REAL((b)) * GSL_IMAG((c)) + GSL_IMAG((b)) * GSL_REAL((c)); \
+} while (FALSE)
+
+#define NCM_COMPLEX_INC_MUL_MUL_REAL(a,b,c,d) \
+do { \
+  GSL_REAL((a)) += (GSL_REAL((b)) * GSL_REAL((c)) - GSL_IMAG((b)) * GSL_IMAG((c))) * (d); \
+  GSL_IMAG((a)) += (GSL_REAL((b)) * GSL_IMAG((c)) + GSL_IMAG((b)) * GSL_REAL((c))) * (d); \
+} while (FALSE)
+
+#define NCM_COMPLEX_MUL_REAL(a,b,c) \
+do { \
+  GSL_REAL((a)) = GSL_REAL((b)) * (c); \
+  GSL_IMAG((a)) = GSL_IMAG((b)) * (c); \
+} while (FALSE)
+
+#define NCM_COMPLEX_MUL(a,b) \
+do { \
+  gdouble temp = GSL_REAL((a)) * GSL_REAL((b)) - GSL_IMAG((a)) * GSL_IMAG((b)); \
+  GSL_IMAG(a) = GSL_REAL((a)) * GSL_IMAG((b)) + GSL_IMAG((a)) * GSL_REAL((b)); \
+  GSL_REAL(a) = temp; \
+} while (FALSE)
+
+#define NCM_COMPLEX_ADD(a,b) \
+do { \
+  GSL_REAL(a) += GSL_REAL((b)); \
+  GSL_IMAG(a) += GSL_IMAG((b)); \
+} while (FALSE)
+
+#define NCM_COMPLEX_MUL_CONJUGATE(a,b) \
+do { \
+  gdouble temp = GSL_REAL((a)) * GSL_REAL((b)) + GSL_IMAG((a)) * GSL_IMAG((b)); \
+  GSL_IMAG(a) = - GSL_REAL((a)) * GSL_IMAG((b)) + GSL_IMAG((a)) * GSL_REAL((b)); \
+  GSL_REAL(a) = temp; \
+} while (FALSE)
+
+#define NCM_CFG_DEFAULT_SQLITE3_FILENAME "data_observation.sqlite3"
+
 #define NCM_WRITE_INT32(_ff,_ii) do { gint32 _temp_i = GINT32_TO_BE ((_ii)); if (fwrite (&_temp_i, sizeof(gint32), (1), _ff) != 1) g_error ("NCM_WRITE_INT32: io error"); } while (FALSE)
 #define NCM_WRITE_UINT32(_ff,_ii) do { guint32 _temp_i = GUINT32_TO_BE ((_ii)); if (fwrite (&_temp_i, sizeof(guint32), (1), _ff) != 1) g_error ("NCM_WRITE_UINT32: io error"); } while (FALSE)
 
@@ -116,16 +230,6 @@ typedef union _NcmDoubleInt64
 
 #define NCM_READ_DOUBLE(_ff,_ii) do { NcmDoubleInt64 _iii; if (fread (&_iii.i, sizeof(gint64), (1), _ff) != 1) g_error ("NCM_READ_DOUBLE: io error"); _iii.i = GINT64_FROM_BE (_iii.i); _ii = _iii.x; } while (FALSE)
 
-gchar *ncm_cfg_command_line (gchar *argv[], gint argc);
-
-void ncm_cfg_object_set_property (GObject *obj, const gchar *prop_str);
-GObject *ncm_cfg_create_from_name_params (const gchar *obj_name, GVariant *params);
-GObject *ncm_cfg_create_from_string (const gchar *obj_ser);
-GVariant *ncm_cfg_gvalue_to_gvariant (GValue *val);
-GVariant *ncm_cfg_serialize_to_variant (GObject *obj);
-gchar *ncm_cfg_serialize_to_string (GObject *obj, gboolean valid_variant);
-
-
 G_END_DECLS
 
 #endif /* _NCM_CFG_H */
