@@ -248,11 +248,11 @@ _ncm_fit_reset (NcmFit *fit)
 
 /**
  * ncm_fit_new:
- * @ftype: a #NcmFitType.
- * @algo_name: FIXME
- * @lh: FIXME
- * @mset: FIXME
- * @gtype: FIXME
+ * @ftype: a #NcmFitType
+ * @algo_name: name of the algorithm to be used
+ * @lh: a #NcmLikelihood
+ * @mset: a #NcmMSet
+ * @gtype: a #NcmFitGradType
  *
  * FIXME
  *
@@ -304,10 +304,10 @@ ncm_fit_ref (NcmFit *fit)
 
 /**
  * ncm_fit_copy_new:
- * @fit: a #NcmFit.
- * @lh: FIXME
- * @mset: FIXME
- * @gtype: FIXME
+ * @fit: a #NcmFit
+ * @lh: a #NcmLikelihood
+ * @mset: a #NcmMSet
+ * @gtype: a #NcmFitGradType
  *
  * Duplicates the #NcmFit object with new references for its contents.
  *
@@ -757,7 +757,7 @@ ncm_fit_log_step_error (NcmFit *fit, const gchar *strerror, ...)
  * ncm_fit_log_end:
  * @fit: a #NcmFit
  *
- * FIXME
+ * This function prints in the log the precision with which the best-fit was found.
  */
 void
 ncm_fit_log_end (NcmFit *fit)
@@ -776,9 +776,10 @@ ncm_fit_log_end (NcmFit *fit)
 /**
  * ncm_fit_log_state:
  * @fit: a #NcmFit
- * @m2lnL: FIXME
+ * @m2lnL: minus two times the logarithm base e of the likelihood.
  *
- * FIXME
+ * This function prints in the log the current state.
+ * 
  */
 void
 ncm_fit_log_state (NcmFit *fit, gdouble m2lnL)
@@ -811,7 +812,7 @@ ncm_fit_log_state (NcmFit *fit, gdouble m2lnL)
 /**
  * ncm_fit_log_step:
  * @fit: a #NcmFit
- * @m2lnL: FIXME
+ * @m2lnL: minus two times the logarithm base e of the likelihood.
  *
  * FIXME
  */
@@ -960,9 +961,12 @@ ncm_fit_fishermatrix_print (NcmFit *fit, FILE *out, gchar *header)
 /**
  * ncm_fit_data_m2lnL_val:
  * @fit: a #NcmFit
- * @data_m2lnL: (out): FIXME
+ * @data_m2lnL: (out): minus two times the logarithm base e of the likelihood.
  *
- * FIXME
+ * This function computes minus two times the logarithm base e of the likelihood 
+ * using only the data set and not considering any prior. The result is set 
+ * on @data_m2lnL.
+ * 
  */
 void
 ncm_fit_data_m2lnL_val (NcmFit *fit, gdouble *data_m2lnL)
@@ -973,9 +977,12 @@ ncm_fit_data_m2lnL_val (NcmFit *fit, gdouble *data_m2lnL)
 /**
  * ncm_fit_priors_m2lnL_val:
  * @fit: a #NcmFit
- * @priors_m2lnL: (out): FIXME
+ * @priors_m2lnL: (out): minus two times the logarithm base e of the likelihood.
  *
- * FIXME
+ * This function computes minus two times the logarithm base e of the likelihood 
+ * using the data set and taking into account the assumed priors. The result is 
+ * set on @priors_m2lnL.
+ * 
  */
 void
 ncm_fit_priors_m2lnL_val (NcmFit *fit, gdouble *priors_m2lnL)
@@ -986,7 +993,7 @@ ncm_fit_priors_m2lnL_val (NcmFit *fit, gdouble *priors_m2lnL)
 /**
  * ncm_fit_m2lnL_val:
  * @fit: a #NcmFit
- * @m2lnL: (out): FIXME
+ * @m2lnL: (out): minus two times the logarithm base e of the likelihood. 
  *
  * FIXME
  */
@@ -1177,7 +1184,7 @@ ncm_fit_m2lnL_val_grad_an (NcmFit *fit, gdouble *result, NcmVector *df)
 /**
  * ncm_fit_m2lnL_val_grad_nd_fo:
  * @fit: a #NcmFit
- * @m2lnL: (out): FIXME
+ * @m2lnL: (out): minus two times the logarithm base e of the likelihood.
  * @grad: a #NcmVector
  *
  * FIXME
@@ -1210,7 +1217,7 @@ ncm_fit_m2lnL_val_grad_nd_fo (NcmFit *fit, gdouble *m2lnL, NcmVector *grad)
 /**
  * ncm_fit_m2lnL_val_grad_nd_ce:
  * @fit: a #NcmFit
- * @m2lnL: FIXME
+ * @m2lnL: minus two times the logarithm base e of the likelihood.
  * @grad: a #NcmVector
  *
  * FIXME
@@ -1225,7 +1232,7 @@ ncm_fit_m2lnL_val_grad_nd_ce (NcmFit *fit, gdouble *m2lnL, NcmVector *grad)
 /**
  * ncm_fit_m2lnL_val_grad_nd_ac:
  * @fit: a #NcmFit
- * @m2lnL: (out): FIXME
+ * @m2lnL: (out): minus two times the logarithm base e of the likelihood.
  * @grad: a #NcmVector
  *
  * FIXME
@@ -1529,7 +1536,7 @@ ncm_fit_numdiff_m2lnL_covar (NcmFit *fit)
   if (ret == GSL_SUCCESS)
   {
     ret = gsl_linalg_cholesky_invert (NCM_MATRIX_GSL (fit->fstate->covar));
-    NC_TEST_GSL_RESULT ("ncm_fit_numdiff_m2lnL_covar[gsl_linalg_cholesky_invert]", ret);
+    NCM_TEST_GSL_RESULT ("ncm_fit_numdiff_m2lnL_covar[gsl_linalg_cholesky_invert]", ret);
   }
   else if (ret == GSL_EDOM)
   {
@@ -1543,16 +1550,16 @@ ncm_fit_numdiff_m2lnL_covar (NcmFit *fit)
     g_warning ("ncm_fit_numdiff_m2lnL_covar: covariance matrix not positive definite, errors are not trustworthy.");
     
     ret1 = gsl_linalg_LU_decomp (NCM_MATRIX_GSL (LU), p, &signum);
-    NC_TEST_GSL_RESULT ("ncm_fit_numdiff_m2lnL_covar[gsl_linalg_LU_decomp]", ret1);
+    NCM_TEST_GSL_RESULT ("ncm_fit_numdiff_m2lnL_covar[gsl_linalg_LU_decomp]", ret1);
     
     ret1 = gsl_linalg_LU_invert (NCM_MATRIX_GSL (LU), p, NCM_MATRIX_GSL (fit->fstate->covar));
-    NC_TEST_GSL_RESULT ("ncm_fit_numdiff_m2lnL_covar[gsl_linalg_LU_invert]", ret1);
+    NCM_TEST_GSL_RESULT ("ncm_fit_numdiff_m2lnL_covar[gsl_linalg_LU_invert]", ret1);
     
     gsl_permutation_free (p);
     ncm_matrix_free (LU);
   }
   else
-    NC_TEST_GSL_RESULT ("ncm_fit_numdiff_m2lnL_covar[gsl_linalg_cholesky_decomp]", ret);
+    NCM_TEST_GSL_RESULT ("ncm_fit_numdiff_m2lnL_covar[gsl_linalg_cholesky_decomp]", ret);
   fit->fstate->has_covar = TRUE;
 }
 
@@ -1608,13 +1615,13 @@ ncm_fit_prob (NcmFit *fit, NcmModelID mid, guint pid, gdouble a, gdouble b)
   F.function = &fit_dprob;
   F.params = &dprob_arg;
 
-  w = nc_integral_get_workspace();
+  w = ncm_integral_get_workspace();
   if (fit->mtype > NCM_FIT_RUN_MSGS_NONE)
     g_message ("#");
-  error_code = gsl_integration_qags (&F, a, b, 1e-10, NC_INT_ERROR, NC_INT_PARTITION, *w, &result, &error);
+  error_code = gsl_integration_qags (&F, a, b, 1e-10, NCM_INTEGRAL_ERROR, NCM_INTEGRAL_PARTITION, *w, &result, &error);
   if (fit->mtype > NCM_FIT_RUN_MSGS_NONE)
     g_message ("\n");
-  NC_TEST_GSL_RESULT ("ncm_fit_prob", error_code);
+  NCM_TEST_GSL_RESULT ("ncm_fit_prob", error_code);
   ncm_memory_pool_return (w);
 
   ncm_fit_free (fit_val);
@@ -1810,9 +1817,9 @@ ncm_fit_function_error (NcmFit *fit, NcmMSetFunc *func, gdouble z, gboolean pret
    NCM_FUNC_DF (func, fit->mset, fit->pt, z, fit->df);
 
    ret = gsl_blas_dgemv (CblasNoTrans, 1.0, NCM_MATRIX_GSL (fit->fstate->covar), ncm_vector_gsl (fit->df), 0.0, ncm_vector_gsl (tmp1));
-   NC_TEST_GSL_RESULT("ncm_fit_function_error[covar.v]", ret);
+   NCM_TEST_GSL_RESULT("ncm_fit_function_error[covar.v]", ret);
    ret = gsl_blas_ddot (ncm_vector_gsl (fit->df), ncm_vector_gsl (tmp1), &result);
-   NC_TEST_GSL_RESULT("ncm_fit_function_error[v.covar.v]", ret);
+   NCM_TEST_GSL_RESULT("ncm_fit_function_error[v.covar.v]", ret);
 
    if (pretty_print)
    g_message ("# % -12.4g +/- % -12.4g\n", NCM_FUNC_F(func, fit->mset, z), sqrt(result));
@@ -1852,21 +1859,21 @@ ncm_fit_function_cov (NcmFit *fit, NcmMSetFunc *func1, gdouble z1, NcmMSetFunc *
    NCM_FUNC_DF (func2, fit->mset, fit->pt, z2, tmp2);
 
    ret = gsl_blas_dgemv (CblasNoTrans, 1.0, NCM_MATRIX_GSL (fit->fstate->covar), ncm_vector_gsl (tmp1), 0.0, ncm_vector_gsl (fit->df));
-   NC_TEST_GSL_RESULT("ncm_fit_function_error[covar.v]", ret);
+   NCM_TEST_GSL_RESULT("ncm_fit_function_error[covar.v]", ret);
    ret = gsl_blas_ddot (ncm_vector_gsl (fit->df), ncm_vector_gsl (tmp1), &result);
-   NC_TEST_GSL_RESULT("ncm_fit_function_error[v.covar.v]", ret);
+   NCM_TEST_GSL_RESULT("ncm_fit_function_error[v.covar.v]", ret);
    s1 = sqrt(result);
 
    ret = gsl_blas_dgemv (CblasNoTrans, 1.0, NCM_MATRIX_GSL (fit->fstate->covar), ncm_vector_gsl (tmp2), 0.0, ncm_vector_gsl (fit->df));
-   NC_TEST_GSL_RESULT("ncm_fit_function_error[covar.v]", ret);
+   NCM_TEST_GSL_RESULT("ncm_fit_function_error[covar.v]", ret);
    ret = gsl_blas_ddot (ncm_vector_gsl (fit->df), ncm_vector_gsl (tmp2), &result);
-   NC_TEST_GSL_RESULT("ncm_fit_function_error[v.covar.v]", ret);
+   NCM_TEST_GSL_RESULT("ncm_fit_function_error[v.covar.v]", ret);
    s2 = sqrt(result);
 
    ret = gsl_blas_dgemv (CblasNoTrans, 1.0, NCM_MATRIX_GSL (fit->fstate->covar), ncm_vector_gsl (tmp1), 0.0, ncm_vector_gsl (fit->df));
-   NC_TEST_GSL_RESULT("ncm_fit_function_error[covar.v]", ret);
+   NCM_TEST_GSL_RESULT("ncm_fit_function_error[covar.v]", ret);
    ret = gsl_blas_ddot (ncm_vector_gsl (fit->df), ncm_vector_gsl (tmp2), &result);
-   NC_TEST_GSL_RESULT("ncm_fit_function_error[v.covar.v]", ret);
+   NCM_TEST_GSL_RESULT("ncm_fit_function_error[v.covar.v]", ret);
    cor = result / (s1*s2);
 
    if (pretty_print)
