@@ -25,10 +25,11 @@
 /**
  * SECTION:ncm_sparam
  * @title: Model Scalar Parameter Description
- * @short_description: Describes the properties of a scalar parameter.
+ * @short_description: Describes the properties of a scalar parameter
  *
  * This object comprises the necessary properties to define a scalar parameter.
  * It is used by #NcmModel to store the description of the scalar model parameters.
+ * 
  */
 
 #ifdef HAVE_CONFIG_H
@@ -120,7 +121,21 @@ ncm_sparam_copy (NcmSParam *sparam)
 void
 ncm_sparam_free (NcmSParam *sparam)
 {
-  g_clear_object (&sparam);
+  g_object_unref (sparam);
+}
+
+/**
+ * ncm_sparam_clear:
+ * @sparam: a #NcmSParam.
+ *
+ * Atomically decrements the reference count of @sparam by one. If the reference count drops to 0,
+ * all memory allocated by @sparam is released. Set the pointer to NULL.
+ *
+ */
+void
+ncm_sparam_clear (NcmSParam **sparam)
+{
+  g_clear_object (sparam);
 }
 
 /**
