@@ -66,13 +66,13 @@ typedef enum _NcmVectorInternal
 struct _NcmVectorClass
 {
   /*< private >*/
-  GInitiallyUnownedClass parent_class;
+  GObjectClass parent_class;
 };
 
 struct _NcmVector
 {
   /*< private >*/
-  GInitiallyUnowned parent_instance;
+  GObject parent_instance;
   GArray *a;
   gsl_vector *gv;
   gsl_vector_view vv;
@@ -86,17 +86,18 @@ GType ncm_vector_get_type (void) G_GNUC_CONST;
 #define NCM_VECTOR_DATA(cv) ((cv)->vv.vector.data)
 
 NcmVector *ncm_vector_new (gsize n);
-NcmVector *ncm_vector_new_sunk (gsize n);
 NcmVector *ncm_vector_new_gsl (gsl_vector *gv);
 NcmVector *ncm_vector_new_gsl_static (gsl_vector *gv);
 NcmVector *ncm_vector_new_array (GArray *a);
 NcmVector *ncm_vector_new_data_slice (gdouble *d, const gsize size, const gsize stride);
 NcmVector *ncm_vector_new_data_malloc (gdouble *d, const gsize size, const gsize stride);
 NcmVector *ncm_vector_new_data_static (gdouble *d, const gsize size, const gsize stride);
+NcmVector *ncm_vector_new_variant (GVariant *var);
 NcmVector *ncm_vector_ref (NcmVector *cv);
 const NcmVector *ncm_vector_new_data_const (const gdouble *d, const gsize size, const gsize stride);
 
 NcmVector *ncm_vector_get_subvector (NcmVector *cv, const gsize k, const gsize size);
+GVariant *ncm_vector_get_variant (NcmVector *v);
 
 G_INLINE_FUNC const NcmVector *ncm_vector_new_gsl_const (const gsl_vector *v);
 G_INLINE_FUNC gdouble ncm_vector_get (const NcmVector *cv, const guint i);
@@ -246,8 +247,7 @@ G_INLINE_FUNC GArray *
 ncm_vector_get_array (NcmVector *cv)
 {
   g_assert (cv->a != NULL);
-  g_array_ref (cv->a);
-  return cv->a;
+  return g_array_ref (cv->a); 
 }
 
 G_INLINE_FUNC GArray *
