@@ -330,7 +330,7 @@ _nc_data_cluster_ncount_binned_f (NcmMSet *mset, gpointer obj, const gdouble *x,
 }
 
 /**
- * nc_data_cluster_ncount_binned_new_function: (skip)
+ * nc_data_cluster_ncount_binned_create_func: (skip)
  * @cad: a #NcClusterAbundance
  *
  * FIXME
@@ -338,7 +338,7 @@ _nc_data_cluster_ncount_binned_f (NcmMSet *mset, gpointer obj, const gdouble *x,
  * Returns: FIXME
  */
 NcmMSetFunc *
-nc_data_cluster_ncount_binned_new_function (NcClusterAbundance *cad)
+nc_data_cluster_ncount_binned_create_func (NcClusterAbundance *cad)
 {
   NcmMSetFunc *func = ncm_mset_func_new (_nc_data_cluster_ncount_binned_f, 1, 1, cad, (GDestroyNotify) nc_cluster_abundance_free);
   return func;
@@ -395,9 +395,8 @@ _nc_data_cluster_ncount_prepare (NcmData *data, NcmMSet *mset)
 
 /**
  * _nc_data_cluster_ncount_resample:
- * @mset: a #NcmModel.
- * @model: FIXME
- * @data: FIXME
+ * @data: a #NcmData.
+ * @mset: a #NcmMSet.
  *
  * This function generates random numbers which are used to obtain redshift
  * and mass (logarithm base e) values...
@@ -499,7 +498,7 @@ _nc_data_cluster_ncount_resample (NcmData *data, NcmMSet *mset)
 
   ncount->np = NCM_MATRIX_NROWS (ncount->z_obs);
 
-  //printf ("Generated %ld, Expected %10.5g\n", ncount->np, nc_cluster_abundance_n (cad, cosmo));
+  printf ("Generated %ld, Expected %10.5g\n", ncount->np, nc_cluster_abundance_n (cad, cosmo));
   
   if (data->desc != NULL)
     g_free (data->desc);
@@ -774,7 +773,7 @@ nc_data_cluster_ncount_bin_data (NcmData *data, gsl_vector *nodes)
     }
   }
 
-  nc_data_poisson_init_from_histogram (data_cpoisson, hist);
+  ncm_data_poisson_init_from_histogram (data_cpoisson, hist);
 
   gsl_histogram_free (hist);
 
