@@ -73,8 +73,8 @@ main (gint argc, gchar *argv[])
 {
   GError *error = NULL;
   GOptionContext *context;
-  NcDataSet *ds;
-  NcLikelihood *lh;
+  NcmDataset *dset;
+  NcmLikelihood *lh;
   NcmFit *fit = NULL;
   NcHICosmoQConst *qconst;
   NcHICosmoDEXcdm *xcdm;
@@ -98,96 +98,86 @@ main (gint argc, gchar *argv[])
   ncm_model_param_set (NCM_MODEL (xcdm), NC_HICOSMO_DE_OMEGA_X, RESAMPLE_OMEGA_LAMBDA);
   ncm_model_param_set (NCM_MODEL (xcdm), NC_HICOSMO_DE_XCDM_W, RESAMPLE_OMEGA);
 
-  ds = nc_dataset_new ();
+  dset = ncm_dataset_new ();
   if (snia_id != -1)
   {
-	NcData *snia = nc_data_distance_mu_snia (dist, snia_id);
-	nc_dataset_append_data (ds, snia);
+    NcmData *snia = nc_data_dist_mu_new (dist, snia_id);
+    ncm_dataset_append_data (dset, snia);
+    ncm_data_free (snia);
   }
 
   if (resample)
-	nc_dataset_resample (ds, mset_xcdm, TRUE);
+    ncm_dataset_resample (dset, mset_xcdm);
 
-  lh = nc_likelihood_new (ds);
+  lh = ncm_likelihood_new (dset);
 
 #define SIM_NUM 20000
   if (least_squares)
   {
-	gint i;
-	gsl_vector *gen_q_0 = gsl_vector_alloc (SIM_NUM);
-	fit = ncm_fit_new (lh, mset, NCM_FIT_TYPE_LEAST_SQUARES, NCM_FIT_GRAD_ANALYTICAL);
-	if (!ncm_fit_run (fit, NC_BF_MAX_ITER, verbose))
-	  g_error ("Fail to fit, use different initial conditions");
-	ncm_fit_log_info (fit);
-	ncm_fit_numdiff_m2lnL_covar (fit);
-	ncm_fit_log_covar (fit);
+    gint i;
+    gsl_vector *gen_q_0 = gsl_vector_alloc (SIM_NUM);
+    fit = ncm_fit_new (NCM_FIT_TYPE_GSL_LS, NULL, lh, mset, NCM_FIT_GRAD_ANALYTICAL);
+    if (!ncm_fit_run (fit, verbose))
+      g_error ("Fail to fit, use different initial conditions");
+    ncm_fit_log_info (fit);
+    ncm_fit_numdiff_m2lnL_covar (fit);
+    ncm_fit_log_covar (fit);
 
-	if (FALSE)
-	{
-	  for (i = 0; i < SIM_NUM; i++)
-	  {
-		nc_dataset_resample (lh->ds, mset_xcdm, FALSE);
-		ncm_fit_log_info (fit);
-		ncm_fit_numdiff_m2lnL_covar (fit);
-		ncm_fit_log_covar (fit);
-		gsl_vector_set (gen_q_0, i, ncm_mset_param_get (fit->mset, NC_HICOSMO_ID, NC_HICOSMO_QCONST_Q));
-		if ( i%10 == 0 )
-		{
-		  printf ("# sample size = %d\n", i+1);
-		  printf ("q: meam = %g, sigma = %g\n", gsl_stats_mean (gen_q_0->data, gen_q_0->stride, i+1),
-		          gsl_stats_sd (gen_q_0->data, gen_q_0->stride, i+1));
-		  fflush (stdout);
-		}
-	  }
-	  printf ("# sample size = %d\n", i);
-	  printf ("q: meam = %g, sigma = %g\n", gsl_stats_mean (gen_q_0->data, gen_q_0->stride, i),
-	          gsl_stats_sd (gen_q_0->data, gen_q_0->stride, i));
-	}
+    if (FALSE)
+    {
+      for (i = 0; i < SIM_NUM; i++)
+      {
+        ncm_dataset_resample (lh->dset, mset_xcdm);
+        ncm_fit_log_info (fit);
+        ncm_fit_numdiff_m2lnL_covar (fit);
+        ncm_fit_log_covar (fit);
+        gsl_vector_set (gen_q_0, i, ncm_mset_param_get (fit->mset, NC_HICOSMO_ID, NC_HICOSMO_QCONST_Q));
+        if ( i%10 == 0 )
+        {
+          printf ("# sample size = %d\n", i+1);
+          printf ("q: meam = %g, sigma = %g\n", gsl_stats_mean (gen_q_0->data, gen_q_0->stride, i+1),
+                  gsl_stats_sd (gen_q_0->data, gen_q_0->stride, i+1));
+          fflush (stdout);
+        }
+      }
+      printf ("# sample size = %d\n", i);
+      printf ("q: meam = %g, sigma = %g\n", gsl_stats_mean (gen_q_0->data, gen_q_0->stride, i),
+              gsl_stats_sd (gen_q_0->data, gen_q_0->stride, i));
+    }
   }
 
   if (multimin)
   {
-	if (z == 0.0 || TRUE)
-	{
-	  ncm_model_param_set (NCM_MODEL (qconst), NC_HICOSMO_QCONST_OMEGA_T, 1.0);
-	  ncm_mset_param_set_ftype (mset, NC_HICOSMO_ID, NC_HICOSMO_QCONST_OMEGA_T, NCM_PARAM_TYPE_FIXED);
-	}
+    if (z == 0.0 || TRUE)
+    {
+      ncm_model_param_set (NCM_MODEL (qconst), NC_HICOSMO_QCONST_OMEGA_T, 1.0);
+      ncm_mset_param_set_ftype (mset, NC_HICOSMO_ID, NC_HICOSMO_QCONST_OMEGA_T, NCM_PARAM_TYPE_FIXED);
+    }
 
-	fit = ncm_fit_new (lh, mset, NCM_FIT_TYPE_LEAST_SQUARES, NCM_FIT_GRAD_ANALYTICAL);
+    fit = ncm_fit_new (NCM_FIT_TYPE_GSL_LS, NULL, lh, mset, NCM_FIT_GRAD_ANALYTICAL);
 
-	if (!ncm_fit_run (fit, NC_BF_MAX_ITER, verbose))
-	  g_error ("Fail to fit, use different initial conditions");
-	if (print_data)
-	{
-	  gdouble err_inf, err_sup;
-	  if (z != 0.0f && FALSE)
-	  {
-		ncm_fit_cr_1dim (fit, NC_HICOSMO_ID, 0, ncm_c_stats_1sigma (), 1, &err_inf, &err_sup);
-		ncm_fit_cr_1dim (fit, NC_HICOSMO_ID, 1, ncm_c_stats_1sigma (), 1, &err_inf, &err_sup);
-	  }
-	  printf("%g",z);
-	  ncm_fit_cr_1dim (fit, NC_HICOSMO_ID, 2, ncm_c_stats_1sigma (), 1, &err_inf, &err_sup);
-	}
+    if (!ncm_fit_run (fit, verbose))
+      g_error ("Fail to fit, use different initial conditions");
   }
 
   if (print_E)
   {
-	gdouble dz[] = {0.09, 0.17, 0.27, 0.4, 0.88, 1.3, 1.43, 1.53, 1.75};
-	gint i;
-	gint n = sizeof (dz)/sizeof(gdouble);
-	gdouble E = ncm_mset_param_get (fit->mset, NC_HICOSMO_ID, NC_HICOSMO_QCONST_E);
-	for (i = 0; i < n && dz[i] <= interval; i++)
-	{
-	  gdouble dE = nc_hicosmo_qlinear_dE (dz[i], z, ncm_mset_param_get (fit->mset, NC_HICOSMO_ID, NC_HICOSMO_QCONST_Q), 0.0);
-	  printf ("\t%g\t%g\t%g\n", dz[i], E * dE, E * dE * ncm_c_hubble_cte_wmap ());
-	}
+    gdouble dz[] = {0.09, 0.17, 0.27, 0.4, 0.88, 1.3, 1.43, 1.53, 1.75};
+    gint i;
+    gint n = sizeof (dz)/sizeof(gdouble);
+    gdouble E = ncm_mset_param_get (fit->mset, NC_HICOSMO_ID, NC_HICOSMO_QCONST_E);
+    for (i = 0; i < n && dz[i] <= interval; i++)
+    {
+      gdouble dE = nc_hicosmo_qlinear_dE (dz[i], z, ncm_mset_param_get (fit->mset, NC_HICOSMO_ID, NC_HICOSMO_QCONST_Q), 0.0);
+      printf ("\t%g\t%g\t%g\n", dz[i], E * dE, E * dE * ncm_c_hubble_cte_wmap ());
+    }
   }
 
   ncm_model_free (NCM_MODEL (qconst));
   ncm_model_free (NCM_MODEL (xcdm));
   ncm_mset_free (mset);
   ncm_mset_free (mset_xcdm);
-  nc_likelihood_free (lh);
-  nc_dataset_free0 (ds, TRUE);
+  ncm_likelihood_free (lh);
+  ncm_dataset_free (dset);
   return 0;
 }
